
%==========================================================================
% Combine concentration measurements (2 ranges: 0-2g/l and 0-30g/l)
%==========================================================================

% Composition 1: max conc around 2 g/l  
time_01_oslim       = time_01;       
oslim_top_01a       = oslim1_cal_01;
oslim_mid_01a       = oslim2_cal_01;
oslim_bot_01a       = oslim3_cal_01;
oslim_top_01b       = oslim4_cal_01;
oslim_bot_01b       = oslim6_cal_01;

% Composition 2
lag_02              = 65;           % Time lag between rot. speed compu and flume
break_02            = 4779+lag_02;  % Break point between 0 - 2 and 0 - 30 g/l range
time_02_oslim       = time_02-lag_02;       
oslim_top_02        = [oslim4_cal_02(1:break_02) oslim1_cal_02(break_02+1:end)]';
oslim_mid_02        = [                          oslim2_cal_02(break_02+1:end)]';
oslim_bot_02        = [oslim6_cal_02(1:break_02) oslim3_cal_02(break_02+1:end)]';

% Composition 3
lag_03              = 88;           % Time lag between rot. speed compu and flume
break_03            = 5414+lag_03;  % Break point between 0 - 2 and 0 - 30 g/l range
time_03_oslim       = time_03-lag_03;  
oslim_top_03        = [oslim4_cal_03(1:break_03) oslim1_cal_03(break_03+1:end)]';
oslim_mid_03        = [                          oslim2_cal_03(break_03+1:end)]';
oslim_bot_03        = [oslim6_cal_03(1:break_03) oslim3_cal_03(break_03+1:end)]';



%==========================================================================
% Calculate mean + maximum concentration
%==========================================================================

oslim_mean_01a = [
    (oslim4_cal_01 + oslim6_cal_01)' / 2
    ];
oslim_mean_01b = [
    (oslim1_cal_01 + oslim2_cal_01 + oslim3_cal_01)' / 3
    ];

oslim_mean_02 = [
    (oslim4_cal_02(1:break_02)     + oslim6_cal_02(1:break_02)                                    )' / 2
    (oslim1_cal_02(break_02+1:end) + oslim2_cal_02(break_02+1:end) + oslim3_cal_02(break_02+1:end))' / 3
    ];

oslim_mean_03 = [
    (oslim4_cal_03(1:break_03)     + oslim6_cal_03(1:break_03)                                    )' / 2
    (oslim1_cal_03(break_03+1:end) + oslim2_cal_03(break_03+1:end) + oslim3_cal_03(break_03+1:end))' / 3
    ];

conc_max_01 = max(oslim_mean_01a);
conc_max_02 = max(oslim_mean_02);
conc_max_03 = max(oslim_mean_03);



%==========================================================================
% Determine concentration profiles 
%==========================================================================

time_prof_01 = [ % oslim time [s]
    4500
    7500
    10000 
    ];
time_prof_02 = [ % oslim time [s]
    4500
    7500
    10000 
    ];
time_prof_03 = [ % oslim time [s]
    3500
    5750
    7000 
    ];

loc_oslim_1 = [ % height of oslim sockets with reference to bottom flume [m]
    0.225
    0.175
    0.125
    ];

conc_prof1_02 = [
    mean(oslim_top_02((time_prof_02(1)-200)           :(time_prof_02(1)+200)))
    0
    mean(oslim_bot_02((time_prof_02(1)-200)           :(time_prof_02(1)+200)))
    %---------------------------
    mean(oslim_top_02((time_prof_02(2)-200)           :(time_prof_02(2)+200)))
    mean(oslim_mid_02((time_prof_02(2)-break_02+1-200):(time_prof_02(2)-break_02+1+200)))
    mean(oslim_bot_02((time_prof_02(2)-200)           :(time_prof_02(2)+200)))
    %---------------------------
    mean(oslim_top_02((time_prof_02(3)-200)           :(time_prof_02(3)+200)))
    mean(oslim_mid_02((time_prof_02(3)-break_02+1-200):(time_prof_02(3)-break_02+1+200)))
    mean(oslim_bot_02((time_prof_02(3)-200)           :(time_prof_02(3)+200)))
    ];

conc_prof1_03 = [
    mean(oslim_top_03((time_prof_03(1)-200)           :(time_prof_03(1)+200)))
    0
    mean(oslim_bot_03((time_prof_03(1)-200)           :(time_prof_03(1)+200)))
    %---------------------------
    mean(oslim_top_03((time_prof_03(2)-200)           :(time_prof_03(2)+200)))
    mean(oslim_mid_03((time_prof_03(2)-break_03+1-200):(time_prof_03(2)-break_03+1+200)))
    mean(oslim_bot_03((time_prof_03(2)-200)           :(time_prof_03(2)+200)))
    %---------------------------
    mean(oslim_top_03((time_prof_03(3)-200)           :(time_prof_03(3)+200)))
    mean(oslim_mid_03((time_prof_03(3)-break_03+1-200):(time_prof_03(3)-break_03+1+200)))
    mean(oslim_bot_03((time_prof_03(3)-200)           :(time_prof_03(3)+200)))
    oslim_bot_03(time_prof_03(3))
    ];
    


















